You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by jw...@apache.org on 2009/03/21 00:00:54 UTC

svn commit: r756797 [1/4] - in /myfaces/trinidad/branches/jwaldman_StyleMap: trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/ trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/ trinidad-impl/src/main/java/org/ap...

Author: jwaldman
Date: Fri Mar 20 23:00:53 2009
New Revision: 756797

URL: http://svn.apache.org/viewvc?rev=756797&view=rev
Log:
more changes to the Style api.

Modified:
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/Style.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/AdjustableBorderPainter.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/skin/XhtmlSkin.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/StyleSheetRenderer.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/BaseStyle.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CSSStyle.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CoreStyle.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/cache/FileSystemStyleCache.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/GlobalHeaderRenderer.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/TabBarRenderer.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/GlobalHeaderRenderer.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/TabBarRenderer.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/xhtml/XhtmlLafUtils.java
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimal-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalIE-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalIERtl-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalInacc-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalPPC-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalSaf-golden.xml
    myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimalScrRdr-golden.xml

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/Style.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/Style.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/AdjustableBorderPainter.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/AdjustableBorderPainter.java Fri Mar 20 23:00:53 2009
@@ -151,7 +151,7 @@
   {
     if (style != null)
     {
-      String value = style.getProperty(propertyName);
+      String value = style.getProperties().get(propertyName);
 
       if (value != null)
       {

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/skin/XhtmlSkin.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/skin/XhtmlSkin.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/skin/XhtmlSkin.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/skin/XhtmlSkin.java Fri Mar 20 23:00:53 2009
@@ -18,6 +18,9 @@
  */
 package org.apache.myfaces.trinidadinternal.renderkit.core.skin;
 
+import java.util.HashMap;
+import java.util.Map;
+
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.SkinProperties;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.SkinSelectors;
 import org.apache.myfaces.trinidadinternal.skin.icon.ContextImageIcon;
@@ -102,17 +105,26 @@
                  null,
                  SkinSelectors.QUICK_SELECT_DISABLED_ICON_STYLE_CLASS,
                  null);
-
-  private static final CSSStyle spinboxTopStyle = new CSSStyle();
-  private static final CSSStyle spinboxBottomStyle = new CSSStyle();
-
+  
+  private static final Map<String, String> _spinboxTopStyleMap;
+  private static final Map<String, String> _spinboxBottomStyleMap;
+  
   static
   {
+    // does this matter if it's not an ArrayMap?
+    _spinboxTopStyleMap = new HashMap<String, String>();
+    _spinboxTopStyleMap.put("display", "block");
     // this is needed for the image
-    spinboxTopStyle.setProperty("display", "block");
-    spinboxBottomStyle.setProperty("display", "block");
-    spinboxBottomStyle.setProperty("padding-top", "2px");
+    _spinboxBottomStyleMap = new HashMap<String, String>();
+    _spinboxBottomStyleMap.put("display", "block");
+    _spinboxBottomStyleMap.put("padding-top", "2px");
+
   }
+  
+  private static final CSSStyle spinboxTopStyle = new CSSStyle(_spinboxTopStyleMap);
+  private static final CSSStyle spinboxBottomStyle = new CSSStyle(_spinboxBottomStyleMap);
+
+
 
   // Icons array
   private static final Object[] _CUSTOMIZABLE_ICONS = new Object[]

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/StyleSheetRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/StyleSheetRenderer.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/StyleSheetRenderer.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/StyleSheetRenderer.java Fri Mar 20 23:00:53 2009
@@ -31,8 +31,10 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.component.core.CoreStyleSheet;
 import org.apache.myfaces.trinidad.context.RenderingContext;
+import org.apache.myfaces.trinidad.style.Style;
 import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRenderingContext;
 import org.apache.myfaces.trinidadinternal.style.StyleContext;
+import org.apache.myfaces.trinidadinternal.style.StyleMap;
 import org.apache.myfaces.trinidadinternal.style.StyleProvider;
 
 
@@ -92,6 +94,7 @@
       // Check if we want to write out the css into the page or not. In portlet mode the 
       // producer tries to share the consumer's stylesheet if it matches exactly.
       boolean suppressStylesheet = _isSuppressStylesheet(context, arc);
+            
       if (!suppressStylesheet)
       {
         if (uris != null && !uris.isEmpty())
@@ -161,6 +164,54 @@
     }
   }
 
+  // TODO DELETE THIS TEST
+  private void _testGetStyleBySelector(RenderingContext arc)
+    {
+      StyleContext sContext = ((CoreRenderingContext) arc).getStyleContext();
+      StyleProvider provider = sContext.getStyleProvider();
+      if (provider != null)
+      {
+
+        // Check if we want to write out the css into the page or not. In portlet mode the 
+        // producer tries to share the consumer's stylesheet if it matches exactly.
+        // jmw
+        StyleMap styleMap = provider.getStyleMap(sContext);
+        String[] selectors = {".AFInstructionText", // selector
+                              "af|inputText::content", // selector
+                              "af|treeTable::expansion", // selector
+                              "af|treeTable::locator", // selector
+                              "af|inputText:disabled.AFFieldTextMarker::content",  // selector
+                              "af|foo af|bar", // selector
+                              ".AFDefaultFont:alias", // nothing, since currently it's in the wrong format to be a named sele ctor
+                              ".AFDefaultFont",// nothing, since currently it's in the wrong format to be a named sele ctor
+                              "AFDefaultFont"};// name
+          
+        System.out.println("getStyleBySelector");
+        for (int i=0; i < selectors.length; i++)
+        {
+          String selector = selectors[i];
+          Style style = styleMap.getStyleBySelector(sContext,selector);
+          if (style != null)
+            System.out.println(selector+" inlineString is " + style.toInlineString());
+          else
+            System.out.println("no styles for " + selector);
+        }
+        System.out.println("");
+        System.out.println("getStyleByName");
+        for (int i=0; i < selectors.length; i++)
+        {
+          String selector = selectors[i];
+          Style style = styleMap.getStyleByName(sContext,selector);
+          if (style != null)
+            System.out.println(selector+" inlineString is " + style.toInlineString());
+          else
+            System.out.println("no styles for " + selector);
+        }
+      }
+    }
+
+
+
 
   // In the portlet environment, the consumer might like the producers to share its stylesheet
   // for performance reasons. To indicate this the producer sends a 

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/BaseStyle.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/BaseStyle.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CSSStyle.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CSSStyle.java Fri Mar 20 23:00:53 2009
@@ -58,10 +58,13 @@
    * All of the properties from the specified Style object are
    * copied into this CSSStyle.
    */
+   /********
   public CSSStyle(Style style)
   {
     super(style);
   }
+***/
+
 
   /**
    * Converts the style to a String suitable for use as an inline style
@@ -74,27 +77,23 @@
 
     if (inline != null)
       return inline;
-
-    Iterator<Object> e = getPropertyNames();
+    
+    Map<String, String> properties = getProperties();
     StringBuffer buffer = new StringBuffer(_DEFAULT_BUFFER_SIZE);
-    boolean first = true;
-
-    if ( e != null )
+    boolean first = true;   
+    
+    for (Map.Entry<String, String> entrySet : properties.entrySet())
     {
-      while (e.hasNext())
-      {
-        if (first)
-          first = false;
-        else
-          buffer.append(";");
-
-        String name = (String)e.next();
-        String value = getProperty(name);
-
-        buffer.append(name);
-        buffer.append(":");
-        buffer.append(value);
-      }
+
+      if (first)
+        first = false;
+      else
+        buffer.append(";");
+      String name = entrySet.getKey();
+      String value = entrySet.getValue();
+      buffer.append(name);
+      buffer.append(":");
+      buffer.append(value);
     }
 
     inline = buffer.toString();
@@ -108,7 +107,9 @@
   }
 
   /**
-   * Sets the specified property value.
+   * Sets the specified property value. If the properties are all known up front,
+   * it is better for performance to use the CSSStyle(Map&lt;String, String> properties) constructor
+   * than to create an empty CSSStyle and call setProperty for each property.
    */
   @Override
   public void setProperty(String name, String value)
@@ -130,30 +131,33 @@
     throws PropertyParseException
   {
     Object value = null;
+    
+    Map<String, String> properties = getProperties();
+    
 
     if (key == CoreStyle.BACKGROUND_KEY)
     {
-      value = CSSUtils.parseColor(getProperty(_BACKGROUND_NAME));
+      value = CSSUtils.parseColor(properties.get(_BACKGROUND_NAME));
     }
     else if (key == CoreStyle.FOREGROUND_KEY)
     {
-      value = CSSUtils.parseColor(getProperty(_FOREGROUND_NAME));
+      value = CSSUtils.parseColor(properties.get(_FOREGROUND_NAME));
     }
     else if (key == CoreStyle.FONT_SIZE_KEY)
     {
-      value = CSSUtils.parseFontSize(getProperty(_FONT_SIZE_NAME));
+      value = CSSUtils.parseFontSize(properties.get(_FONT_SIZE_NAME));
     }
     else if (key == CoreStyle.FONT_STYLE_KEY)
     {
-      value = CSSUtils.parseFontStyle(getProperty(_FONT_STYLE_NAME));
+      value = CSSUtils.parseFontStyle(properties.get(_FONT_STYLE_NAME));
     }
     else if (key == CoreStyle.FONT_WEIGHT_KEY)
     {
-      value = CSSUtils.parseFontWeight(getProperty(_FONT_WEIGHT_NAME));
+      value = CSSUtils.parseFontWeight(properties.get(_FONT_WEIGHT_NAME));
     }
     else if (key == CoreStyle.FONT_FAMILIES_KEY)
     {
-      String[] families = CSSUtils.parseFontFamilies(getProperty(
+      String[] families = CSSUtils.parseFontFamilies(properties.get(
                                                      _FONT_FAMILY_NAME));
 
       if (families != null)
@@ -161,7 +165,7 @@
     }
     else if (key == CoreStyle.TEXT_ANTIALIAS_KEY)
     {
-      String antialiased = getProperty(_TEXT_ANTIALIAS_NAME);
+      String antialiased = properties.get(_TEXT_ANTIALIAS_NAME);
       if ((antialiased != null) && "true".equalsIgnoreCase(antialiased))
       {
         value = Boolean.TRUE;

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CoreStyle.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CoreStyle.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CoreStyle.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CoreStyle.java Fri Mar 20 23:00:53 2009
@@ -22,15 +22,16 @@
 
 /**
  * A CoreStyle object defines a set of visual (or aural) style properties.
- * The CoreStyle interface exposes two method for retrieving properties:
- * getProperty() and getParsedProperty().  getProperty()
- * takes a String property name and returns a String property value.
+ * The CoreStyle interface exposes one method for retrieving properties:
+ * getParsedProperty().
  * getParsedProperty() takes a key object (eg. FONT_WEIGHT_KEY) and
  * returns the parsed, typed, Java object which represents the
  * property value.  The type of the returned object is key-specific,
  * eg. for FONT_WEIGHT_KEY, an java.lang.Integer is returned.
  * For BACKGROUND_KEY, a java.awt.Color is returned.
- *
+ * @deprecated Use the Style interface instead. The parsedProperties should
+ * not be used in new code. It's only used now in the image generation code
+ * that is not used.
  * @version $Name:  $ ($Revision: adfrt/faces/adf-faces-impl/src/main/java/oracle/adfinternal/view/faces/style/Style.java#0 $) $Date: 10-nov-2005.18:57:56 $
  */
 public interface CoreStyle extends Style

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/cache/FileSystemStyleCache.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/cache/FileSystemStyleCache.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/cache/FileSystemStyleCache.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/cache/FileSystemStyleCache.java Fri Mar 20 23:00:53 2009
@@ -1420,7 +1420,7 @@
          // System.out.println("Add selector to _resolvedStyles " + selector);
           // create a Style Object from the StyleNode object
           Style style = _convertStyleNode(_resolvedStyles[i]);
-          _resolvedStyleMap.put(selector, style);
+          _resolvedSelectorStyleMap.put(selector, style);
 
  
         }
@@ -1429,7 +1429,7 @@
           String name = _resolvedStyles[i].getName();
           // create a Style Object from the StyleNode object
           Style style = _convertStyleNode(_resolvedStyles[i]);
-          _resolvedStyleMap.put(name, style);
+          _resolvedNamedSelectorsStyleMap.put(name, style);
 
         }
       }
@@ -1445,8 +1445,7 @@
       if (_selectorMap == null)
         _selectorMap = _createMap();
 
-      Style oldStyle = _getStyle(context, _selectorMap, selector, "", false);
-      Style newStyle = _resolvedStyleMap.get(selector);
+      Style newStyle = _resolvedSelectorStyleMap.get(selector);
       return newStyle;
       //return _getStyle(context, _selectorMap, selector, "", false);
     }
@@ -1460,7 +1459,8 @@
       if (_classMap == null)
         _classMap = _createMap();
       String prefix = (styleClass.indexOf('|') > -1) ? "" : ".";
-      return _getStyle(context, _classMap, styleClass, prefix , false);
+      return _resolvedSelectorStyleMap.get(prefix+styleClass);
+      //return _getStyle(context, _classMap, styleClass, prefix , false);
     }
 
     // Implementation of StyleMap.getStyleByClass()
@@ -1471,13 +1471,15 @@
     {
       if (_nameMap == null)
         _nameMap = _createMap();
-
-      return _getStyle(context, _nameMap, name, "", true);
+      Style newStyle = _resolvedNamedSelectorsStyleMap.get(name);
+      return newStyle;
+      //return _getStyle(context, _nameMap, name, "", true);
     }
 
     // Do all of the real work
     // TODO if using the _resolvedStyles works, then we can get rid of all the
     // excess code in StyleSheetDocument to getStyleByName, etc.
+    /**** jmw. Won't need this with the new APIs.
     private Style _getStyle(
       StyleContext       context,
       Map<String, Style> map,
@@ -1531,6 +1533,7 @@
       map.put(id, style);
       return style;
     }
+*/
     
     public Style _convertStyleNode(StyleNode styleNode)
     {
@@ -1566,7 +1569,9 @@
     private Hashtable<String, Style> _classMap;
     private Hashtable<String, Style> _nameMap;
     
-    private ConcurrentMap<String, Style> _resolvedStyleMap = 
+    private ConcurrentMap<String, Style> _resolvedSelectorStyleMap = 
+      new ConcurrentHashMap<String, Style>();
+    private ConcurrentMap<String, Style> _resolvedNamedSelectorsStyleMap = 
       new ConcurrentHashMap<String, Style>();
     
     private StyleNode[] _resolvedStyles;

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/GlobalHeaderRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/GlobalHeaderRenderer.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/GlobalHeaderRenderer.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/GlobalHeaderRenderer.java Fri Mar 20 23:00:53 2009
@@ -20,6 +20,8 @@
 
 import java.io.IOException;
 
+import java.util.Map;
+
 import javax.faces.context.ResponseWriter;
 
 import org.apache.myfaces.trinidad.component.UIXNavigationLevel;
@@ -329,7 +331,7 @@
                                                 AF_MENU_BAR_STYLE_CLASS);
       if (style != null)
       {
-        String minHeight = style.getProperty("min-height");
+        String minHeight = style.getProperties().get("min-height");
         renderSpacer(context, null, minHeight);
       }
     }

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/TabBarRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/TabBarRenderer.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/TabBarRenderer.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/desktop/TabBarRenderer.java Fri Mar 20 23:00:53 2009
@@ -407,7 +407,7 @@
 
       if (style != null)
       {
-        String width = style.getProperty("width");
+        String width = style.getProperties().get("width");
 
         // As an optimization, we do not render the tabBar
         // separator if the af|menuTabs::separator's width is 0px.

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/GlobalHeaderRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/GlobalHeaderRenderer.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/GlobalHeaderRenderer.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/GlobalHeaderRenderer.java Fri Mar 20 23:00:53 2009
@@ -157,10 +157,11 @@
       if (classStyle != null)
       {
         ResponseWriter writer = context.getResponseWriter();
+        
 
         // write the cell's background color property
         writer.writeAttribute("bgcolor",
-                              classStyle.getProperty("background-color"), null);
+                              classStyle.getProperties().get("background-color"), null);
       }
     }
     else

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/TabBarRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/TabBarRenderer.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/TabBarRenderer.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/pda/TabBarRenderer.java Fri Mar 20 23:00:53 2009
@@ -76,7 +76,7 @@
 
         // write the cell's background color property
         writer.writeAttribute("bgcolor",
-                              classStyle.getProperty("background-color"), null);
+                              classStyle.getProperties().get("background-color"), null);
       }
     }
     else

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/xhtml/XhtmlLafUtils.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/xhtml/XhtmlLafUtils.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/xhtml/XhtmlLafUtils.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/ui/laf/base/xhtml/XhtmlLafUtils.java Fri Mar 20 23:00:53 2009
@@ -243,7 +243,7 @@
                                        className);
       if (classStyle != null)
       {
-        return classStyle.getProperty(propertyName);
+        return classStyle.getProperties().get(propertyName);
       }
 
       return null;
@@ -582,10 +582,13 @@
     String stylePropertyName
     )
   {
-    String value = (style1 != null)
-                     ? style1.getProperty(stylePropertyName)
-                     : null;
+    String value = null;
+    if (style1 != null)
+    {
+      value = style1.getProperties().get(stylePropertyName);
+    }
 
+    
     if (value != null)
     {
       return value;
@@ -594,7 +597,8 @@
     {
       if (style2 != null)
       {
-        return style2.getProperty(stylePropertyName);
+        
+        return style2.getProperties().get(stylePropertyName);
       }
       else
       {

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimal-golden.xml
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimal-golden.xml?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimal-golden.xml (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/test/resources/org/apache/myfaces/trinidadinternal/renderkit/golden/inputNumberSpinbox-minimal-golden.xml Fri Mar 20 23:00:53 2009
@@ -94,7 +94,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -207,7 +207,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -320,7 +320,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -433,7 +433,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -546,7 +546,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -659,7 +659,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -772,7 +772,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -885,7 +885,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -998,7 +998,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1111,7 +1111,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1224,7 +1224,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1337,7 +1337,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1450,7 +1450,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1563,7 +1563,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1676,7 +1676,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1788,7 +1788,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -1911,7 +1911,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2023,7 +2023,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2135,7 +2135,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2248,7 +2248,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2365,7 +2365,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2485,7 +2485,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2597,7 +2597,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2710,7 +2710,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2822,7 +2822,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -2940,7 +2940,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3052,7 +3052,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3170,7 +3170,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3282,7 +3282,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3400,7 +3400,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3512,7 +3512,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3625,7 +3625,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3738,7 +3738,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3851,7 +3851,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -3964,7 +3964,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4077,7 +4077,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4190,7 +4190,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4303,7 +4303,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4416,7 +4416,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4529,7 +4529,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4642,7 +4642,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4755,7 +4755,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4868,7 +4868,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -4981,7 +4981,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5094,7 +5094,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5206,7 +5206,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5318,7 +5318,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5430,7 +5430,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5526,7 +5526,7 @@
                          alt="decrement disabled"
                          border="0"
                          height="5"
-                         style="display:block;padding-top:2px"
+                         style="padding-top:2px;display:block"
                          title="decrement disabled"
                          width="5"
                          src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdnd.png"
@@ -5637,7 +5637,7 @@
                            alt="decrement"
                            border="0"
                            height="5"
-                           style="display:block;padding-top:2px"
+                           style="padding-top:2px;display:block"
                            title="decrement"
                            width="5"
                            src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5764,7 +5764,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5855,7 +5855,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -5946,7 +5946,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6037,7 +6037,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6128,7 +6128,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6219,7 +6219,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6310,7 +6310,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6401,7 +6401,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6492,7 +6492,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6583,7 +6583,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6674,7 +6674,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6765,7 +6765,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6856,7 +6856,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -6947,7 +6947,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -7038,7 +7038,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -7128,7 +7128,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -7218,7 +7218,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -7308,7 +7308,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
@@ -7382,7 +7382,7 @@
                      alt="decrement disabled"
                      border="0"
                      height="5"
-                     style="display:block;padding-top:2px"
+                     style="padding-top:2px;display:block"
                      title="decrement disabled"
                      width="5"
                      src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdnd.png"
@@ -7471,7 +7471,7 @@
                        alt="decrement"
                        border="0"
                        height="5"
-                       style="display:block;padding-top:2px"
+                       style="padding-top:2px;display:block"
                        title="decrement"
                        width="5"
                        src="uri-attr:encoded-resource-url:/test-context-path/adf/images/spbxdn.png"
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/Style.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-api/src/main/java/org/apache/myfaces/trinidad/style/Style.java Fri Mar 20 23:00:53 2009
@@ -19,36 +19,22 @@
  *  under the License.
  */
 
-import java.util.Iterator;
+import java.util.Map;
 
 /**
  * A Style object defines a set of visual (or aural) style properties.
  * The Style interface exposes one method for retrieving properties:
- * getProperty().  getProperty() takes a String property name and 
- * returns a String property value. You can get an Iterator of PropertyNames
- * by calling getPropretyNames(). 
+ * getProperties().  getProperties() returns a Map<String, String> of the propery name as the
+ * key and the property value as the value.
  *
  */
 public interface Style
 {
 
   /**
    * Returns the names of the properties defined by this style.
    */
-  // -= Simon Lessard =-
-  // FIXME: This should be changed to <String> once the issues 
-  //        with ArrayMap are fixed. ATM (2006-08-04) ArrayMap 
-  //        have huge problem working with anything but Object???
-  // TODO???
-  public Iterator<Object> getPropertyNames();
-
-  /**
-   * Returns the value of the property with the specified name.
-   *
-   * @param name The property name for the property to return
-   */
-  public String getProperty(String name);
-
+  public Map<String, String> getProperties();
 
   /**
    * Converts the style to a String suitable for use as an inline style
@@ -19,36 +19,22 @@
 
   /**
-   * Returns the names of the properties defined by this style.
+   * Returns a Map of the properties (name/value) defined by this style.
    */

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/AdjustableBorderPainter.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/image/painter/AdjustableBorderPainter.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================
--- myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/BaseStyle.java (original)
+++ myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/BaseStyle.java Fri Mar 20 23:00:53 2009
@@ -19,60 +19,59 @@
 package org.apache.myfaces.trinidadinternal.style;
 
 import java.io.Serializable;
-import java.util.Map;
-import java.util.Iterator;
 
-import org.apache.myfaces.trinidad.style.Style;
+import java.util.Collections;
+import java.util.Map;
 
 import org.apache.myfaces.trinidad.util.ArrayMap;
 
 /**
  * Base class for Style implementations
+ * TODO Remove the ParsedProperty code from Trinidad. It is only used for
+ * the un-used image generation code.
+ * TODO Then remove CoreStyle and implement the public Style object instead.
  * @version $Name:  $ ($Revision: adfrt/faces/adf-faces-impl/src/main/java/oracle/adfinternal/view/faces/style/BaseStyle.java#0 $) $Date: 10-nov-2005.18:57:54 $
  */
 abstract public class BaseStyle implements CoreStyle, Serializable
 {
   /**
    * Creates an empty BaseStyle.
    */
   public BaseStyle()
   {
+    _propertiesMap = Collections.emptyMap();
   }
 
   /**
    * Creates a BaseStyle with the specified properties
    *
    * @param properties The properties of this style.  The
    *   values must be Strings.
    */
-  public BaseStyle(Map<String, String> properties)
+  public BaseStyle(Map<String, String> propertiesMap)
   {
-    if ((properties != null) && (properties.size() > 0))
+    if ((propertiesMap != null) && (propertiesMap.size() > 0))
     {
-      // Initialize the properties array
-      int length = properties.size() * 2;
-      _properties = new String[length];
-
-      int i = 0;
-      for(Map.Entry<String, String> entry : properties.entrySet())
-      {
-        String key   = entry.getKey();
-        String value = entry.getValue();
-
-        // -= Simon Lessard =-
-        // FIXME: If key is ever null, NullPointerException will occurs
-        _properties[i*2]   = key.toLowerCase();
-        _properties[i*2+1] = value;
-        i++;
-      }
+      // Initialize the propertiesMap with an ArrayMap implementation.
+      // ArrayMap is fast reads.
+      int length = propertiesMap.size() * 2;
+      _propertiesMap = new ArrayMap<String, String>(length);
+      
+      _propertiesMap.putAll(propertiesMap);
     }
+    else
+      _propertiesMap = Collections.emptyMap();
   }
 
   /**
    * Creates a BaseStyle from an arbitrary Style object.
    */
+   /***
   public BaseStyle(Style style)
   {
+    System.out.println("BaseStyle with constructor style is called");
+
     if ( style != null)
     {
 
@@ -107,26 +106,16 @@
 
       _properties = properties;
     }
-  }
 
-  /**
-   * Returns the names of the properties defined by this style.
-   * <p>
-   * The property names can be any valid property name.
-   */
-  public Iterator<Object> getPropertyNames()
-  {
-    return ArrayMap.getKeys(_properties);
   }
+    **/
 
   /**
-   * Returns the value of the property with the specified name.
-   *
-   * @param name The property name for the property to return
+   * Returns an UnmodifiableMap
    */
-  public String getProperty(String name)
+  public Map<String, String> getProperties()
   {
-    return (String)ArrayMap.get(_properties, name.toLowerCase());
+    return Collections.unmodifiableMap(_propertiesMap);
   }
 
 
@@ -196,10 +185,13 @@
 
     synchronized (this)
     {
-      _properties = ArrayMap.remove(_properties, name);
+      if (_propertiesMap == null || _propertiesMap.isEmpty())
+        _propertiesMap = new ArrayMap<String, String>();
+      _propertiesMap.put(name, value);
+      //_properties = ArrayMap.remove(_properties, name);
 
-      if (value != null)
-        _properties = ArrayMap.put(_properties, name, value);
+     // if (value != null)
+      //  _properties = ArrayMap.put(_properties, name, value);
 
       // We need to reset to parsed properties if our properties change
       // Really, we could just null out the corresponding parsed property
@@ -222,7 +214,7 @@
   abstract protected Object parseProperty(Object key)
     throws PropertyParseException;
 
-  private Object[] _properties;
+  private Map<String, String> _propertiesMap;
   transient private Object[] _parsedProperties;
 
   // Count of parsed properties defined by Style
@@ -19,60 +19,59 @@
 {
   /**
-   * Creates an empty BaseStyle.
+   * Creates an empty BaseStyle. For better performance, 
+   * use the Base(Map&lt;String, String>) constructor.
    */
   public BaseStyle()
@@ -19,60 +19,59 @@
    * Creates a BaseStyle with the specified properties
    *
-   * @param properties The properties of this style.  The
-   *   values must be Strings.
+   * @param propertiesMap The properties of this style.  The
+   *   name and values must be Strings.
    */

Modified: myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CSSStyle.java
URL: http://svn.apache.org/viewvc/myfaces/trinidad/branches/jwaldman_StyleMap/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/style/CSSStyle.java?rev=756797&r1=756796&r2=756797&view=diff
==============================================================================